@@ -2,7 +2,7 @@ from datetime import datetime
 from enum import Enum
 from typing import Dict, List, Optional, Union
 
-from pydantic import BaseModel, EmailStr
+from pydantic import BaseModel, EmailStr, validator
 
 #
 # GENERIC
@@ -92,9 +92,13 @@ class Database(BaseModel):
     databaseEid: str
     databaseName: str
     description: str
-    createTime: datetime
+    createTime: str
     catalogId: str
 
+    # @validator('createTime')
+    # def create_time_iso_8601(cls, v: str):
+    #    ...
+
 
 class Databases(BaseModel):
     __root__: List[Database]
@@ -133,8 +137,8 @@ class GeneralInfo(BaseModel):
     tableEid: str
     tableName: str
     databaseName: str
-    createTime: datetime
-    updateTime: datetime
+    createTime: str  # TODO: validator
+    updateTime: str  # TODO: validator
     tableType: str
     createdBy: str
     versionId: str
@@ -159,8 +163,8 @@ class TableSummary(BaseModel):
     tableName: str
     databaseEid: str
     databaseName: str
-    createTime: datetime
-    updateTime: datetime
+    createTime: str  # TODO: validator
+    updateTime: str  # TODO: validator
     location: str
 
 
@@ -174,7 +178,7 @@ class TableSummaries(BaseModel):
 class QuerySummary(BaseModel):
     queryExecutionId: str
     queryState: str
-    queryStart: datetime
+    queryStart: str  # TODO: validator
     queryRunTimeMs: int
     queryDataScanned: int
 
@@ -202,8 +206,8 @@ class QueryDetail(BaseModel):
     database: str
     catalog: str
     status: str
-    submissionDate: Union[datetime, str]
-    completionDate: Optional[Union[datetime, str]]
+    submissionDate: str  # TODO: validator
+    completionDate: Optional[str]  # TODO: validator
     errorMessage: Optional[str]
     workGroup: str
     statistics: Statistics
@@ -223,8 +227,8 @@ class Job(BaseModel):  # JobSummary+JobDetails
     jobName: str
     description: str
     role: str
-    createdOn: datetime
-    lastModifiedOn: datetime
+    createdOn: str  # TODO: validator
+    lastModifiedOn: str  # TODO: validator
     glueVersion: str
     maxRetries: int
     allocatedCapacity: int
@@ -235,8 +239,8 @@ class Job(BaseModel):  # JobSummary+JobDetails
     command: Optional[Command]
     defaultArguments: Optional[Dict]
     lastJobRunState: Optional[str]
-    lastStartedOn: Optional[datetime]
-    lastCompletedOn: Optional[datetime]
+    lastStartedOn: Optional[str]  # TODO: validator
+    lastCompletedOn: Optional[str]  # TODO: validator
     lastExecutionTime: Optional[int]
 
 
@@ -250,8 +254,8 @@ class JobRun(BaseModel):
     jobEid: str
     triggerName: Optional[str]
     jobRunState: str
-    startedOn: datetime
-    completedOn: datetime
+    startedOn: str  # TODO: validator
+    completedOn: str  # TODO: validator
     executionTime: int
     errorMessage: Optional[str]
 
